@@ -21,7 +21,7 @@ package MongoDB::DeleteResult;
 # ABSTRACT: MongoDB deletion result object
 
 use version;
-our $VERSION = 'v1.8.2';
+our $VERSION = 'v1.8.3';
 
 use Moo;
 use MongoDB::_Constants;
@@ -61,11 +61,11 @@ MongoDB::DeleteResult - MongoDB deletion result object
 
 =head1 VERSION
 
-version v1.8.2
+version v1.8.3
 
 =head1 SYNOPSIS
 
-    my $result = $coll->delete( { _id => $oid } );
+    my $result = $coll->delete_one( { _id => $oid } );
 
     if ( $result->acknowledged ) {
         ...
